Exception: PinterestDL::InvalidURLError

Inherits:
Error
  • Object
show all
Defined in:
lib/pinterest_dl/errors.rb

Instance Method Summary collapse

Constructor Details

#initialize(message = 'The given URL does not look like a valid Pinterest URL') ⇒ InvalidURLError

Returns a new instance of InvalidURLError.



39
40
41
# File 'lib/pinterest_dl/errors.rb', line 39

def initialize(message = 'The given URL does not look like a valid Pinterest URL')
  super
end