Exception: PinterestDL::InvalidURLError
- Defined in:
- lib/pinterest_dl/errors.rb
Instance Method Summary collapse
-
#initialize(message = 'The given URL does not look like a valid Pinterest URL') ⇒ InvalidURLError
constructor
A new instance of InvalidURLError.
Constructor Details
#initialize(message = 'The given URL does not look like a valid Pinterest URL') ⇒ InvalidURLError
Returns a new instance of InvalidURLError.
39 40 41 |
# File 'lib/pinterest_dl/errors.rb', line 39 def initialize( = 'The given URL does not look like a valid Pinterest URL') super end |